@@ -12,16 +12,14 @@
 #
 ##############################################################################
 """Test not found errors
-
-$Id: test_functional.py 110812 2010-04-13 16:30:31Z thefunny42 $
 """
 
+import doctest
 import re
 import unittest
 
 from zope.testing import renormalizing
 from zope.app.publication.testing import PublicationLayer
-from zope.testing import doctest
 
 
 checker = renormalizing.RENormalizing([
@@ -35,6 +33,10 @@ def test_suite():
         '../methodnotallowed.txt',
         optionflags=optionflags)
     methodnotallowed.layer = PublicationLayer
+    notfound = doctest.DocFileSuite(
+        '../notfound.txt',
+        optionflags=optionflags)
+    notfound.layer = PublicationLayer
     httpfactory = doctest.DocFileSuite(
         '../httpfactory.txt', checker=checker,
         optionflags=optionflags)
@@ -45,6 +47,7 @@ def test_suite():
     site.layer = PublicationLayer
     return unittest.TestSuite((
         methodnotallowed,
+        notfound,
         httpfactory,
         site,))
 
